@@ -259,12 +259,35 @@ CODALAB_ARGUMENTS = [
             'Ingest URL for logging exceptions with Sentry. If not provided, Sentry is not used.'
         ),
     ),
+    # Bundle Manager
+    CodalabArg(
+        name='bundle_manager_worker_timeout_seconds',
+        help='Number of seconds to wait after a worker check-in before determining a worker is offline',
+        type=int,
+        default=60,
+    ),
     # Worker manager
     CodalabArg(
         name='worker_manager_type',
         help='Type of worker manager (azure-batch or aws-batch)',
         default='azure-batch',
     ),
+    CodalabArg(
+        name='worker_manager_worker_work_dir_prefix',
+        help='Prefix to use for each worker\'s working directory of the worker manager',
+        default='/tmp',
+    ),
+    CodalabArg(
+        name='worker_manager_worker_max_work_dir_size',
+        help='Maximum size of the temporary bundle data for a worker of the worker manager',
+        default='10g',
+    ),
+    CodalabArg(
+        name='worker_manager_worker_checkin_frequency_seconds',
+        help='Number of seconds to wait between check-ins for a worker of the worker manager',
+        type=int,
+        default=5,
+    ),
     CodalabArg(
         name='worker_manager_idle_seconds',
         help='Number of seconds workers wait idle before exiting',
